//	Grey-Output Thermal Shader - 1.0
//------------------------------------
float4x4 WorldViewProj : WorldViewProjection;
float4x4 World : WorldIT;
float4 EyePos : EyePos;

//------------------------------------
texture HeatMap
<
	string name = "Null";
>;

//------------------------------------
technique GreyThermal14
{
	pass p0
	{
		VertexShaderConstant[0] = <WorldViewProj>;
		VertexShaderConstant[4] = <World>;
		VertexShaderConstant[11] = <EyePos>;

		VertexShader = asm
		{
			// Initilise Shader
			vs.1.1
			dcl_position	v0
			dcl_normal	v1
			dcl_texcoord	v2
			
			// Define Constants
			def c20, 1.0, 0.5, 0.0, 0.0
			
			// Transform Position to Clip
			m4x4 oPos, v0, c0
			mov oT0, v2
			
			// Move Eye Position to Object Space
			mov r0, c11
			m3x3 r1, r0, c4
			
			// Compute Normalised Eye Vector
			add r1, r1.xyz, -v0
			dp3 r1.w, r1, r1
			rsq r1.w, r1.w
			mul r1, r1, r1.w
			
			// Scale, Bias and Output Eye Vector
			add r1, r1, c20.x
			mul oT1, r1, c20.y
			
			// Scale, Bias and Output Normals
			add r0, v1, c20.x
			mul oT2, r0, c20.y
		};
		
		PixelShader = asm
		{
			// Initialise Shader
			ps.1.4
			def c0, 0.5f, 0.5f, 0.5f, 0.5f
			
			// Load Normals
			texld r0, t0
			texcrd r1.rgb, t1
			texcrd r2.rgb, t2
			
			// Compute Angular Signature
			dp3 r1, r1_bx2, r2_bx2
			mul r1, r1, r0
			
			// Combine with Texture Signature
			mul r0, r0, c0
			mad r0, r1, c0, r0
		};
		
		Texture[0] = <HeatMap>;
		MinFilter[0] = Linear;
		MagFilter[0] = Linear;
		MipFilter[0] = Linear;
	}
}